# Sci-Annot Evaluation Component
This package was developed as part of my master's thesis and used in the evaluation stage.

It produces per-page confusion matrices with multiple classes for predictions in the field of Object Detection, with inter-object dependencies also supported.